@@ -1,4 +1,5 @@
 from enum import Enum
+import os
 import logging
 import asyncio
 import typing
@@ -50,7 +51,13 @@ class ZCCXT:
     )
 
     def __init__(
-        self, api_key: str, api_secret: str, exchange: ExchangeEnum, is_demo=False, identifier=None, disable_db=False
+        self,
+        api_key: str,
+        api_secret: str,
+        exchange: ExchangeEnum,
+        is_demo=False,
+        identifier=None,
+        disable_db=False,
     ):
         if exchange.value not in [e.value for e in ExchangeEnum]:
             raise ECInvalidValue(f"Invalid exchange provided: {exchange}")
@@ -64,7 +71,13 @@ class ZCCXT:
 
     @classmethod
     async def create(
-        cls, api_key: str, api_secret: str, exchange: ExchangeEnum, is_demo=False, identifier=None, disable_db=False
+        cls,
+        api_key: str,
+        api_secret: str,
+        exchange: ExchangeEnum,
+        is_demo=False,
+        identifier=None,
+        disable_db=False,
     ):
         self = cls(api_key, api_secret, exchange, is_demo, identifier, disable_db)
 
@@ -91,6 +104,11 @@ class ZCCXT:
 
         self.client = getattr(ccxt, self.exchange.lower())(params)
 
+        socks_proxy = os.environ.get("SOCKS_PROXY", None)
+        if socks_proxy:
+            self.client.socks_proxy = socks_proxy
+            self.client.ws_socks_proxy = socks_proxy
+
         if not self.db_disabled:
             conn = connections.get("default")
             _, res = await conn.execute_query(
@@ -1149,7 +1167,7 @@ class ZCCXT:
                     amount_precision = int(amount_precision)
                 if self.client.precisionMode == DECIMAL_PLACES:
                     amount_precision = Decimal("10") ** -amount_precision
-                qty = Decimal(proposed_qty).quantize(amount_precision, rounding=ROUND_DOWN)
+                qty = Decimal(str(proposed_qty)).quantize(amount_precision, rounding=ROUND_DOWN)
         except ccxt_errors.InvalidOrder:
             qty = 0.0
 
